@@ -64,7 +64,10 @@ def plugin_wrapper_vollseg():
                 source = Signal.sender()
                 emitter = Signal.current_emitter()
                 if debug:
-                    # print(f'{emitter}: {source} = {args!r}')
+                    print(f'Choosen model_type for StarDist 2D {plugin.model2d_star.value}')
+                    print(f'Choosen model_type for StarDist 3D {plugin.model3d_star.value}')
+                    print(f'Choosen model_type for UNET {plugin.model_unet.value}')
+                    print(f'Choosen model_type for CARE {plugin.model_den.value}')
                     print(f'{str(emitter.name).upper()}: {source.name} = {args!r}')
                 return handler(*args)
 
@@ -144,6 +147,19 @@ def plugin_wrapper_vollseg():
         iouthresh = 0.5,
         prob_map_watershed=True,
     )
+    
+    DEFAULTS_DISPLAY_PARAMETERS = dict(
+        
+        display_prob=True,
+        display_vollseg = True,
+        display_skeleton = True,
+        display_stardist = True,
+        display_unet = True,
+        display_denoised = True,
+        display_markers = True,
+        
+    ) 
+
     CUSTOM_SEG_MODEL_STAR = 'CUSTOM_SEG_MODEL_STAR'
     CUSTOM_SEG_MODEL_UNET = 'CUSTOM_SEG_MODEL_UNET'
     CUSTOM_DEN_MODEL = 'CUSTOM_DEN_MODEL'
@@ -166,7 +182,6 @@ def plugin_wrapper_vollseg():
 
     @functools.lru_cache(maxsize=None)
     def get_model_star(star_seg_model_type, model_star):
-        print(star_seg_model_type)
         if star_seg_model_type == CUSTOM_SEG_MODEL_STAR:
             path_star = Path(model_star)
             path_star.is_dir() or _raise(
@@ -298,23 +313,23 @@ def plugin_wrapper_vollseg():
             widget_type='FloatSpinBox',
             label='Min Size Mask (px)',
             min=0.0,
-            max=1000.0,
-            step=1,
+            max=1000000.0,
+            step=10,
             value=DEFAULTS_VOLL_PARAMETERS['min_size_mask'],
         ),
         min_size=dict(
             widget_type='FloatSpinBox',
             label='Min Size Cells (px)',
             min=0.0,
-            max=1000.0,
-            step=1,
+            max=10000000.0,
+            step=10,
             value=DEFAULTS_VOLL_PARAMETERS['min_size'],
         ),
         max_size=dict(
             widget_type='FloatSpinBox',
             label='Max Size Cells (px)',
-            min=1000.0,
-            max=100000.0,
+            min=1.0,
+            max=100000000.0,
             step=100,
             value=DEFAULTS_VOLL_PARAMETERS['max_size'],
         ),
@@ -371,6 +386,63 @@ def plugin_wrapper_vollseg():
     ):
 
         return plugin_extra_parameters
+    
+    @magicgui(
+       
+        display_prob=dict(
+            widget_type='CheckBox',
+            text='Display Probability Map',
+            value=DEFAULTS_DISPLAY_PARAMETERS['display_prob'],
+        ),
+        display_unet=dict(
+            widget_type='CheckBox',
+            text='Display UNET Results',
+            value=DEFAULTS_DISPLAY_PARAMETERS['display_unet'],
+        ),
+        
+        display_stardist =dict(
+            widget_type='CheckBox',
+            text='Display StarDist Results',
+            value=DEFAULTS_DISPLAY_PARAMETERS['display_stardist'],
+        ),
+        display_markers=dict(
+            widget_type='CheckBox',
+            text='Display Markers Results',
+            value=DEFAULTS_DISPLAY_PARAMETERS['display_markers'],
+        ),
+        display_vollseg=dict(
+            widget_type='CheckBox',
+            text='Display VollSeg Results',
+            value=DEFAULTS_DISPLAY_PARAMETERS['display_vollseg'],
+        ),
+        display_denoised=dict(
+            widget_type='CheckBox',
+            text='Display Denoised Results',
+            value=DEFAULTS_DISPLAY_PARAMETERS['display_denoised'],
+        ),
+        display_skeleton=dict(
+            widget_type='CheckBox',
+            text='Display VollSeg Skeleton Results',
+            value=DEFAULTS_DISPLAY_PARAMETERS['display_skeleton'],
+        ),
+        defaults_display_parameters_button=dict(
+            widget_type='PushButton', text='Restore Display Defaults'
+        ),
+        call_button=False,
+    )
+    def plugin_display_parameters(
+        display_prob,
+        display_unet,
+        display_stardist,
+        display_markers,
+        display_vollseg,
+        display_denoised,
+        display_skeleton,
+        defaults_display_parameters_button,
+        
+    ):
+
+        return plugin_display_parameters
 
     logo = abspath(__file__, 'resources/vollseg_logo_napari.png')
 
@@ -484,6 +556,7 @@ def plugin_wrapper_vollseg():
         progress_bar: mw.ProgressBar,
     ) -> List[napari.types.LayerDataTuple]:
         x = get_data(image)
+        
         axes = axes_check_and_normalize(axes, length=x.ndim)
         progress_bar.label = 'Starting VollSeg'
         if plugin_star_parameters.norm_image:
@@ -649,23 +722,12 @@ def plugin_wrapper_vollseg():
             scale_in_dict = dict(zip(axes, image.scale))
             scale_out = [scale_in_dict.get(a, 1.0) for a in axes_out]     
             
-                
-            if isinstance(model_star, StarDist3D):
-
-                
+            if model_star is not None:   
                 worker = _VollSeg_time(model_star, model_unet, x_reorder, axes_reorder, model_den, scale_out, t, x)
                 worker.returned.connect(return_segment_time)
                 worker.yielded.connect(progress_thread)
 
-            if isinstance(model_star, StarDist2D):
 
-                
-
-                
-                
-                worker = _VollSeg_time(model_star, model_unet, x_reorder, axes_reorder, model_den, scale_out, t, x)
-                worker.returned.connect(return_segment_time)
-                worker.yielded.connect(progress_thread)
             if model_star is None:
                    
                         
@@ -677,19 +739,9 @@ def plugin_wrapper_vollseg():
         else:
             
          
-            # TODO: possible to run this in a way that it can be canceled?
-            if isinstance(model_star, StarDist3D):
-
-                
-                    worker = _Segment(model_star, model_unet, x, axes, model_den,scale_out)
-                    worker.returned.connect(return_segment)
-            if isinstance(model_star, StarDist2D):
-
-                
-                    print('Starting VollSeg')
-                
-                    worker = _Segment(model_star, model_unet, x, axes, model_den,scale_out)
-                    worker.returned.connect(return_segment)
+            worker = _Segment(model_star, model_unet, x, axes, model_den,scale_out)
+            worker.returned.connect(return_segment)
+            
             if model_star is None:
                 
                          
@@ -697,7 +749,7 @@ def plugin_wrapper_vollseg():
                 worker.returned.connect(return_segment_unet)
  
         progress_bar.hide()
-        plugin_star_parameters.n_tiles.value = original_tiling
+        
             
 
     plugin.axes.value = ''
@@ -736,6 +788,14 @@ def plugin_wrapper_vollseg():
     parameter_extra_tab.setLayout(_parameter_extra_tab_layout)
     _parameter_extra_tab_layout.addWidget(plugin_extra_parameters.native)
     tabs.addTab(parameter_extra_tab, 'VollSeg Parameter Selection')
+
+    parameter_display_tab = QWidget()
+    _parameter_display_tab_layout = QVBoxLayout()
+    parameter_display_tab.setLayout(_parameter_display_tab_layout)
+    _parameter_display_tab_layout.addWidget(plugin_display_parameters.native)
+    tabs.addTab(parameter_display_tab, 'Layer Visibility Selection')
+
+
     plugin.native.layout().addWidget(tabs)
 
     def widgets_inactive(*widgets, active):
@@ -745,7 +805,7 @@ def plugin_wrapper_vollseg():
 
     def widgets_valid(*widgets, valid):
         for widget in widgets:
-            widget.native.setStyleSheet('' if valid else 'background-color: lightcoral')
+            widget.native.setStyleSheet('' if valid else 'background-color: red')
             
     class Unet_den_updater:
         def __init__(self, debug=DEBUG):
@@ -765,7 +825,6 @@ def plugin_wrapper_vollseg():
             assert k in vars(self.valid)
             setattr(self.valid, k, bool(valid))
             setattr(self.args, k, args)
-            print('den again',self.valid, self.args)
             self._update()
 
         def help(self, msg):
@@ -776,7 +835,6 @@ def plugin_wrapper_vollseg():
         
         def _update(self):
 
-            print('what is den',plugin.model_den)
             # try to get a hold of the viewer (can be None when plugin starts)
             if self.viewer is None:
                 # TODO: when is this not safe to do and will hang forever?
@@ -799,14 +857,11 @@ def plugin_wrapper_vollseg():
                 widgets_valid(
                     plugin.model_den, plugin.model_folder_den.line_edit, valid=valid,
                 )
-                print('den',plugin.model_den, plugin.model_folder_den.line_edit, valid)
                 if valid:
-                    print(valid)
                     config_den = self.args.model_den
                     axes_den = config_den.get(
                         'axes', 'ZYXC'[-len(config_den['unet_input_shape']) :]
                     )
-                    print('den axes',axes_den)
                     if 'T' in axes_den:
                         raise RuntimeError('model with axis "T" not supported')
                     plugin_extra_parameters.den_model_axes.value = axes_den.replace('C', f'C[{config_den["n_channel_in"]}]')    
@@ -822,7 +877,6 @@ def plugin_wrapper_vollseg():
             def _image_axes(valid):
                 axes, image, err = getattr(self.args, 'image_axes', (None, None, None))
                 
-                print('image axes',axes)
                 widgets_valid(
                     plugin.axes,
                     valid=(
@@ -892,9 +946,7 @@ def plugin_wrapper_vollseg():
             all_valid = False
             help_msg = ''
 
-            print(self.valid.image_axes
-            , self.valid.n_tiles
-            , self.valid.model_den)
+            
             if (
                 self.valid.image_axes
                 and self.valid.n_tiles
@@ -947,7 +999,6 @@ def plugin_wrapper_vollseg():
                         help_msg = f'Model with axes {axes_model_den.replace("C", f"C[{ch_model_den}]")} and image with axes {axes_image.replace("C", f"C[{ch_image}]")} not compatible'
             else:
                 
-                print('Invalid den',self.valid.model_den)
                 _image_axes(self.valid.image_axes)
                 _norm_axes(self.valid.norm_axes)
                 _n_tiles(self.valid.n_tiles)
@@ -982,7 +1033,6 @@ def plugin_wrapper_vollseg():
             assert k in vars(self.valid)
             setattr(self.valid, k, bool(valid))
             setattr(self.args, k, args)
-            print('unet again',self.valid, self.args)
             self._update()
 
         def help(self, msg):
@@ -993,7 +1043,6 @@ def plugin_wrapper_vollseg():
         
         def _update(self):
 
-            print('what is unet',plugin.model_unet)
             # try to get a hold of the viewer (can be None when plugin starts)
             if self.viewer is None:
                 # TODO: when is this not safe to do and will hang forever?
@@ -1018,12 +1067,10 @@ def plugin_wrapper_vollseg():
                 )
                 print('unet',plugin.model_unet, plugin.model_folder_unet.line_edit, valid)
                 if valid:
-                    print(valid)
                     config_unet = self.args.model_unet
                     axes_unet = config_unet.get(
                         'axes', 'ZYXC'[-len(config_unet['unet_input_shape']) :]
                     )
-                    print('unet axes',axes_unet)
                     if 'T' in axes_unet:
                         raise RuntimeError('model with axis "T" not supported')
                     plugin_extra_parameters.unet_model_axes.value = axes_unet.replace('C', f'C[{config_unet["n_channel_in"]}]')    
@@ -1038,7 +1085,6 @@ def plugin_wrapper_vollseg():
             def _image_axes(valid):
                 axes, image, err = getattr(self.args, 'image_axes', (None, None, None))
                 
-                print('image axes',axes)
                 widgets_valid(
                     plugin.axes,
                     valid=(
@@ -1108,10 +1154,7 @@ def plugin_wrapper_vollseg():
             all_valid = False
             help_msg = ''
 
-            print('unet',self.valid.image_axes
-            ,self.valid.n_tiles
-            , self.valid.model_unet
-            ) 
+            
             if (
                 self.valid.image_axes
                 and self.valid.n_tiles
@@ -1143,7 +1186,6 @@ def plugin_wrapper_vollseg():
                         if 'C' in axes_image
                         else 1
                     )
-                    print('Channels',ch_model_unet, ch_image)
                     all_valid = (
                         set(axes_model_unet.replace('C', ''))
                         == set(axes_image.replace('C', '').replace('T', ''))
@@ -1162,7 +1204,6 @@ def plugin_wrapper_vollseg():
                         help_msg = f'Model with axes {axes_model_unet.replace("C", f"C[{ch_model_unet}]")} and image with axes {axes_image.replace("C", f"C[{ch_image}]")} not compatible'
             else:
                 
-                print('Invalid unet',self.valid.model_unet)
                 _image_axes(self.valid.image_axes)
                 _norm_axes(self.valid.norm_axes)
                 _n_tiles(self.valid.n_tiles)
@@ -1200,7 +1241,6 @@ def plugin_wrapper_vollseg():
             assert k in vars(self.valid)
             setattr(self.valid, k, bool(valid))
             setattr(self.args, k, args)
-            print('star again',self.valid, self.args)
             self._update()
 
         def help(self, msg):
@@ -1236,14 +1276,12 @@ def plugin_wrapper_vollseg():
                     valid=valid,
                 )
                 
-                print('star',plugin.model2d_star,plugin.model3d_star, plugin.model_folder_star.line_edit, valid)
                 if valid:
                     config_star = self.args.model_star
                     
                     axes_star = config_star.get(
                         'axes', 'ZYXC'[-len(config_star['net_input_shape']) :]
                     )
-                    print('star axes',axes_star)
                     if 'T' in axes_star:
                         raise RuntimeError('model with axis "T" not supported')
                     plugin_star_parameters.star_model_axes.value = axes_star.replace(
@@ -1261,7 +1299,6 @@ def plugin_wrapper_vollseg():
 
             def _image_axes(valid):
                 axes, image, err = getattr(self.args, 'image_axes', (None, None, None))
-                print('image star axes',axes)
                 widgets_valid(
                     plugin.axes,
                     valid=(
@@ -1457,6 +1494,34 @@ def plugin_wrapper_vollseg():
     @change_handler(plugin_extra_parameters.prob_map_watershed)
     def _prob_map_watershed_change(active: bool):
         plugin_extra_parameters.prob_map_watershed.value = active
+   
+    @change_handler(plugin_display_parameters.display_prob)
+    def _display_prob_map_change(active: bool):
+        plugin_display_parameters.display_prob.value = active
+
+    @change_handler(plugin_display_parameters.display_unet)
+    def _display_unet_change(active: bool):
+        plugin_display_parameters.display_unet.value = active
+
+    @change_handler(plugin_display_parameters.display_stardist)
+    def _display_star_change(active: bool):
+        plugin_display_parameters.display_stardist.value = active
+    
+    @change_handler(plugin_display_parameters.display_denoised)
+    def _display_den_change(active: bool):
+        plugin_display_parameters.display_denoised.value = active
+
+    @change_handler(plugin_display_parameters.display_markers)
+    def _display_den_change(active: bool):
+        plugin_display_parameters.display_markers.value = active
+
+    @change_handler(plugin_display_parameters.display_vollseg)
+    def _display_den_change(active: bool):
+        plugin_display_parameters.display_vollseg.value = active
+  
+    @change_handler(plugin_display_parameters.display_skeleton)
+    def _display_skel_change(active: bool):
+        plugin_display_parameters.display_skeleton.value = active
 
     # ensure that percentile low < percentile high
     @change_handler(plugin_star_parameters.perc_low)
@@ -1584,10 +1649,9 @@ def plugin_wrapper_vollseg():
                 Markers = np.asarray(Markers)
                 Markers = np.moveaxis(Markers, 0, t)
                 Markers = np.reshape(Markers, x.shape)     
-                
                 for layer in list(plugin.viewer.value.layers):
                     
-                    if 'VollSeg Binary' in layer.name:
+                    if  'VollSeg Binary' in layer.name:
                              plugin.viewer.value.layers.remove(layer)
                     if 'Base Watershed Image' in layer.name:
                              plugin.viewer.value.layers.remove(layer)         
@@ -1609,7 +1673,7 @@ def plugin_wrapper_vollseg():
                             
                                 name='Base Watershed Image',
                                 scale=scale_out,
-                                visible=False,
+                                visible=plugin_display_parameters.display_prob.value,
                            
                     )
 
@@ -1617,7 +1681,7 @@ def plugin_wrapper_vollseg():
                         
                             labels,
                           
-                                name='VollSeg labels', scale= scale_out, opacity=0.5, 
+                                name='VollSeg labels', scale= scale_out, opacity=0.5,  visible = plugin_display_parameters.display_vollseg.value
                         
                     )
 
@@ -1628,7 +1692,7 @@ def plugin_wrapper_vollseg():
                                 name='StarDist',
                                 scale=scale_out,
                                 opacity=0.5,
-                                visible=False,
+                                visible=plugin_display_parameters.display_stardist.value,
                            
                     )
                     
@@ -1639,7 +1703,7 @@ def plugin_wrapper_vollseg():
                                 name='VollSeg Binary',
                                 scale=scale_out,
                                 opacity=0.5,
-                                visible=False,
+                                visible=plugin_display_parameters.display_unet.value,
                           
                     )
 
@@ -1650,7 +1714,7 @@ def plugin_wrapper_vollseg():
                                 name='Markers',
                                 scale=scale_out,
                                 opacity=0.5,
-                                visible=False,
+                                visible=plugin_display_parameters.display_markers.value,
                           
                     )
                     plugin.viewer.value.add_labels(
@@ -1660,19 +1724,19 @@ def plugin_wrapper_vollseg():
                                 name='Skeleton',
                                 scale=scale_out,
                                 opacity=0.5,
-                                visible=False,
+                                visible=plugin_display_parameters.display_skeleton.value,
                             
                     )
-                if plugin.den_model_type.value != DEFAULTS_MODEL['model_den_none']:
-                    plugin.viewer.value.add_image(
-                        
-                            denoised_image,
-                         
-                                name='Denoised Image',
-                                scale=scale_out,
-                                visible=False,
+                    if plugin.den_model_type.value != DEFAULTS_MODEL['model_den_none']:
+                        plugin.viewer.value.add_image(
                             
-                        )
+                                denoised_image,
+                            
+                                    name='Denoised Image',
+                                    scale=scale_out,
+                                    visible=plugin_display_parameters.display_denoised.value,
+                                
+                            )
                 
                 
     
@@ -1690,7 +1754,6 @@ def plugin_wrapper_vollseg():
           if plugin.star_seg_model_type.value == DEFAULTS_MODEL['model_star_none']:
               
               unet_mask, denoised_image = res
-                  
           for layer in list(plugin.viewer.value.layers):
               
               if 'VollSeg Binary' in layer.name:
@@ -1715,7 +1778,7 @@ def plugin_wrapper_vollseg():
                       
                           name='Base Watershed Image',
                           scale=scale_out,
-                          visible=False,
+                          visible=plugin_display_parameters.display_prob.value,
                      
               )
 
@@ -1723,7 +1786,7 @@ def plugin_wrapper_vollseg():
                   
                       labels,
                     
-                          name='VollSeg labels', scale= scale_out, opacity=0.5, 
+                          name='VollSeg labels', scale= scale_out, opacity=0.5, visible = plugin_display_parameters.display_vollseg.value 
                   
               )
 
@@ -1734,7 +1797,7 @@ def plugin_wrapper_vollseg():
                           name='StarDist',
                           scale=scale_out,
                           opacity=0.5,
-                          visible=False,
+                          visible=plugin_display_parameters.display_stardist.value,
                      
               )
               
@@ -1745,7 +1808,7 @@ def plugin_wrapper_vollseg():
                           name='VollSeg Binary',
                           scale=scale_out,
                           opacity=0.5,
-                          visible=False,
+                          visible=plugin_display_parameters.display_unet.value,
                     
               )
 
@@ -1756,7 +1819,7 @@ def plugin_wrapper_vollseg():
                           name='Markers',
                           scale=scale_out,
                           opacity=0.5,
-                          visible=False,
+                          visible=plugin_display_parameters.display_markers.value,
                     
               )
               plugin.viewer.value.add_labels(
@@ -1766,19 +1829,19 @@ def plugin_wrapper_vollseg():
                           name='Skeleton',
                           scale=scale_out,
                           opacity=0.5,
-                          visible=False,
+                          visible=plugin_display_parameters.display_skeleton.value,
                       
               )
-          if plugin.den_model_type.value != 'NODEN':
-              plugin.viewer.value.add_image(
-                  
-                      denoised_image,
-                   
-                          name='Denoised Image',
-                          scale=scale_out,
-                          visible=False,
-                      
-                  )
+              if plugin.den_model_type.value != DEFAULTS_MODEL['model_den_none']:
+                    plugin.viewer.value.add_image(
+                        
+                            denoised_image,
+                        
+                                name='Denoised Image',
+                                scale=scale_out,
+                                visible=plugin_display_parameters.display_denoised.value,
+                            
+                        )
               
     
     def return_segment_unet_time(pred):
@@ -1809,15 +1872,15 @@ def plugin_wrapper_vollseg():
                       unet_mask, name ='VollSeg Binary',
                           scale= scale_out,
                           opacity=0.5,
-                          visible=True)
-              if plugin.den_model_type.value != 'NODEN':
+                          visible=plugin_display_parameters.display_unet.value)
+              if plugin.den_model_type.value != DEFAULTS_MODEL['model_den_none']:
                   plugin.viewer.value.add_image(
                       
                           denoised_image,
                        
                               name='Denoised Image',
                               scale=scale_out,
-                              visible=False,
+                              visible=plugin_display_parameters.display_denoised.value,
                           
                       )
               
@@ -1839,15 +1902,15 @@ def plugin_wrapper_vollseg():
                       unet_mask, name ='VollSeg Binary',
                           scale= scale_out,
                           opacity=0.5,
-                          visible=True)
-              if plugin.den_model_type.value != 'NODEN':
+                          visible=plugin_display_parameters.display_unet.value)
+              if plugin.den_model_type.value != DEFAULTS_MODEL['model_den_none']:
                  plugin.viewer.value.add_image(
                      
                          denoised_image,
                       
                              name='Denoised Image',
                              scale=scale_out,
-                             visible=False,
+                             visible=plugin_display_parameters.display_denoised.value,
                          
                      )
       
@@ -1892,7 +1955,8 @@ def plugin_wrapper_vollseg():
              
             yield count
             pre_res.append(VollSeg(_x, unet_model = model_unet, n_tiles=plugin_star_parameters.n_tiles.value, axes = axes_reorder, noise_model = noise_model,  RGB = plugin_extra_parameters.isRGB.value,
-                                 iou_threshold = plugin_extra_parameters.iouthresh.value,slice_merge = plugin_extra_parameters.slicemerge.value))
+                                min_size_mask=plugin_extra_parameters.min_size_mask.value,
+                       max_size=plugin_extra_parameters.max_size.value, iou_threshold = plugin_extra_parameters.iouthresh.value,slice_merge = plugin_extra_parameters.slicemerge.value))
         
         pred = pre_res, scale_out, t, x
         return pred           
@@ -1901,6 +1965,8 @@ def plugin_wrapper_vollseg():
     def _Unet( model_unet, x, axes, noise_model, scale_out):
     
         res = VollSeg(x, unet_model = model_unet, n_tiles=plugin_star_parameters.n_tiles.value, axes = axes, noise_model = noise_model,  RGB = plugin_extra_parameters.isRGB.value,
+        min_size_mask=plugin_extra_parameters.min_size_mask.value,
+                       max_size=plugin_extra_parameters.max_size.value,
                      iou_threshold = plugin_extra_parameters.iouthresh.value,slice_merge = plugin_extra_parameters.slicemerge.value)
 
         pred = res, scale_out
@@ -1956,7 +2022,6 @@ def plugin_wrapper_vollseg():
                         
                         key_star = model_class_star, model_name
                         if key_star not in model_star_configs:
-                            print('key stars',key_star, model_star_configs)
                             @thread_worker
                             def _get_model_folder():
                                 return get_model_folder(*key_star)
@@ -2003,7 +2068,6 @@ def plugin_wrapper_vollseg():
         if Signal.sender() is not plugin.model_unet_none:
                 model_class_unet = ( UNET if Signal.sender() is plugin.model_unet else UNET if plugin.model_unet.value is not None and Signal.sender() is None else None ) 
                 
-                print('class unet',model_class_unet, plugin.model_unet)
                 if model_class_unet is not None:
                         plugin_extra_parameters.dounet.value = True  
                         if Signal.sender is not None:
@@ -2011,7 +2075,6 @@ def plugin_wrapper_vollseg():
                         elif plugin.model_unet.value is not None:
                             model_name = plugin.model_unet.value
                         key_unet = model_class_unet, model_name
-                        print('key unets',key_unet, model_unet_configs)
                         if key_unet not in model_unet_configs:
                 
                             @thread_worker
@@ -2055,7 +2118,6 @@ def plugin_wrapper_vollseg():
             if Signal.sender() is not plugin.model_den_none: 
                 model_class_den = ( CARE if Signal.sender() is plugin.model_den else CARE if plugin.model_den.value is not None and Signal.sender() is None else None ) 
             
-                print('class den ',model_class_den)
                 if model_class_den is not None:
 
                     if Signal.sender is not None:
@@ -2063,7 +2125,6 @@ def plugin_wrapper_vollseg():
                     elif plugin.model_unet.value is not None:
                        model_name = plugin.model_unet.value
                     key_den = model_class_den, model_name
-                    print('key denss',key_den, model_den_configs)
                     if key_den not in model_den_configs:
             
                         @thread_worker
@@ -2151,7 +2212,7 @@ def plugin_wrapper_vollseg():
     def _image_change(image: napari.layers.Image):
         ndim = get_data(image).ndim
         
-        plugin.image.tooltip = f'Shape: {get_data(image).shape}'
+        plugin.image.tooltip = f'Shape: {get_data(image).shape, str(image.name)}'
 
         # dimensionality of selected model: 2, 3, or None (unknown)
         ndim_model = None
@@ -2223,11 +2284,7 @@ def plugin_wrapper_vollseg():
         try:
             image is not None or _raise(ValueError('no image selected'))
             value = plugin_star_parameters.n_tiles.get_value()
-            if value is None:
-                update('n_tiles', True, (None, image, None))
-                update_unet('n_tiles', True, (None, image, None))
-                update_den('n_tiles', True, (None, image, None))
-                return
+            
             shape = get_data(image).shape
             try:
                 value = tuple(value)
@@ -2236,23 +2293,35 @@ def plugin_wrapper_vollseg():
                 raise ValueError(f'must be a tuple/list of length {len(shape)}')
             if not all(isinstance(t, int) and t >= 1 for t in value):
                 raise ValueError(f'each value must be an integer >= 1')
-            update('n_tiles', True, (value, image, None))
-            update_unet('n_tiles', True, (value, image, None))
-            update_den('n_tiles', True, (value, image, None))
+            if plugin.star_seg_model_type !=DEFAULTS_MODEL['model_star_none']:    
+               update('n_tiles', True, (value, image, None))
+            if plugin.unet_seg_model_type !=DEFAULTS_MODEL['model_unet_none']:   
+               update_unet('n_tiles', True, (value, image, None))
+            if plugin.den_model_type !=DEFAULTS_MODEL['model_den_none']:   
+               update_den('n_tiles', True, (value, image, None))
         except (ValueError, SyntaxError) as err:
-            update('n_tiles', False, (None, image, err))
-            update_unet('n_tiles', False, (None, image, err))
-            update_den('n_tiles', False, (None, image, err))
+            if plugin.star_seg_model_type !=DEFAULTS_MODEL['model_star_none']:
+               update('n_tiles', False, (None, image, err))
+            if plugin.unet_seg_model_type !=DEFAULTS_MODEL['model_unet_none']:   
+               update_unet('n_tiles', False, (None, image, err))
+            if plugin.den_model_type !=DEFAULTS_MODEL['model_den_none']:   
+               update_den('n_tiles', False, (None, image, err))
     # -------------------------------------------------------------------------
 
     # set thresholds to optimized values for chosen model
-    @change_handler(plugin_star_parameters.set_thresholds, init=False)
+    @change_handler(plugin_star_parameters.set_thresholds, plugin.model_folder_star, init=False)
     def _set_thresholds():
         if model_selected_star in model_star_threshs:
             thresholds = model_star_threshs[model_selected_star]
+            
             plugin_star_parameters.nms_thresh.value = thresholds['nms']
             plugin_star_parameters.prob_thresh.value = thresholds['prob']
 
+        else:
+
+            plugin_star_parameters.nms_thresh.value = DEFAULTS_STAR_PARAMETERS['nms_thresh']
+            plugin_star_parameters.prob_thresh.value = DEFAULTS_STAR_PARAMETERS['prob_thresh']
+
     @change_handler(plugin_extra_parameters.min_size)
     def _min_size_change(value: float):
 
@@ -2286,6 +2355,13 @@ def plugin_wrapper_vollseg():
     def restore_vollseg_param_defaults():
         for k, v in DEFAULTS_VOLL_PARAMETERS.items():
             getattr(plugin_extra_parameters, k).value = v
+     
+    @change_handler(
+        plugin_display_parameters.defaults_display_parameters_button, init=False
+    )
+    def restore_display_param_defaults():
+        for k, v in DEFAULTS_DISPLAY_PARAMETERS.items():
+            getattr(plugin_display_parameters, k).value = v
 
     @change_handler(plugin.defaults_model_button, init=False)
     def restore_model_defaults():
@@ -2359,7 +2435,7 @@ def napari_get_reader(path: str):
         return None
 
 
-@napari_hook_implementation
+""" @napari_hook_implementation
 def napari_experimental_provide_dock_widget():
     return plugin_wrapper_vollseg, dict(name='VollSeg', add_vertical_stretch=True)
 
@@ -2368,12 +2444,12 @@ def napari_experimental_provide_dock_widget():
 def napari_provide_sample_data():
 
     return {
-        'test_image_cell_2d': {
+        'test_image_cell_3d': {
             'data': lambda: [(test_image_ascadian_3d(), {'name': 'ascadian_embryo_3d'})],
             'display_name': 'Embryo Cells (3D)',
         },
-        'test_image_cell_3d': {
+        'test_image_cell_3dt': {
             'data': lambda: [(test_image_carcinoma_3dt(), {'name': 'carcinoma_cells_3dt'})],
             'display_name': 'Breast Cancer Cells (3DT)',
         },
-    }
\ No newline at end of file
+    }  """
\ No newline at end of file
